#
# spec file for package deltarpm
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           deltarpm
Version:        3.6.1
Release:        10.4
Summary:        Tools to Create and Apply deltarpms
License:        BSD-3-Clause
Group:          System/Packages
Url:            https://github.com/rpm-software-management/deltarpm/
Source:         deltarpm-3.6.1.tar.bz2
# PATCH-MISSING-TAG -- See http://wiki.opensuse.org/openSUSE:Packaging_Patches_guidelines
Patch0:         patch.sles8
BuildRequires:  libbz2-devel
BuildRequires:  python-devel
BuildRequires:  rpm-devel
BuildRequires:  xz-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
# we need to build against recent rpm, so avoid the new payload
%define _binary_payload w9.bzdio

%description
This package contains tools to create and apply deltarpms. A deltarpm
contains the difference between an old and a new version of an RPM,
which makes it possible to recreate the new RPM from the deltarpm and
the old one. You do not need to have a copy of the old RPM, because
deltarpms can also work with installed RPMs.

%package -n python-deltarpm
Summary:        Tools to Create and Apply deltarpms
Group:          Development/Languages/Python
Requires:       %{name} = %{version}
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitearch: %global python_sitearch %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib(1)")}
%endif

%description -n python-deltarpm
Python bindings for deltarpm

%prep
%setup -q
%if 0%{?suse_version} < 900
%patch0
%endif

%build
make CC="gcc" CFLAGS="%{optflags}" rpmdumpheader="/usr/lib/rpm/rpmdumpheader" %{?_smp_mflags}
make CC="gcc" CFLAGS="%{optflags}" rpmdumpheader="/usr/lib/rpm/rpmdumpheader" %{?_smp_mflags} python

%install
mkdir -p %{buildroot}%{_prefix}/lib/rpm
make DESTDIR=%{buildroot} prefix="%{_prefix}" libdir="%{_libdir}" mandir="%{_mandir}" rpmdumpheader="/usr/lib/rpm/rpmdumpheader" PYTHONS="python" install
rm -rf %{buildroot}%{_libdir}/python/site-packages/{_deltarpmmodule.so,deltarpm.py} # Remove wrongly installed Python module
mv %{buildroot}%{python_sitearch}/_deltarpm{module,}.so # Fix binary Python module name

%files
%defattr(-,root,root)
%doc README LICENSE.BSD
%{_bindir}/*
%{_mandir}/man8/*
%{_prefix}/lib/rpm/rpmdumpheader

%files -n python-deltarpm
%defattr(-,root,root)
%{python_sitearch}/deltarpm.py
%{python_sitearch}/_deltarpm.so

%changelog
* Tue Nov 24 2015 ro@suse.de
- update to version 3.6.1
  - remove upstreamed patch deltarpm-zlibcppflags.diff
  - fix off-by-one error in delta generation code (bnc#948504)
    This could lead to a segfault in rare circumstances.
  - Return error rather than crashing if we can't allocate memory
  - add newline in missing prelink error
  - do not finish applydeltarpm jobs when in the middle of a request
  - fix zlibcppflags typo
* Mon Jun 10 2013 mls@suse.de
- update to deltarpm-3.6
  * fixes failing applydeltarpm with gzip -9 compression
  * adds a couple of manpages
* Wed Jan 25 2012 saschpe@suse.de
- Package binary Python module, python-deltarpm isn't noarch any more
* Mon Jan 23 2012 saschpe@suse.de
- Run spec-cleaner
- Add python-deltarpm subpackage
* Fri Sep 30 2011 uli@suse.com
- cross-build fix: use %%__cc macro
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
  (cf. packaging guidelines)
- Use %%_smp_mflags for parallel build
* Fri Oct 15 2010 mls@suse.de
- update to current git to get support for the '-m' option,
  which limits memory consumption
* Wed Sep  9 2009 mls@suse.de
- adapt to rpm-4.7 lzma level change
* Mon Aug 24 2009 mls@suse.de
- update to version 3.5
- no changes, just patch integration
* Mon Feb 16 2009 coolo@suse.de
- adapt to xz-devel API changes (could only test makedeltarpm as
  our old deltas can not be applied anymore - resulting md5 is different)
* Wed Oct 22 2008 mls@suse.de
- add lzma and bzip2 devel packages to the buildrequires
* Thu Oct  2 2008 mls@suse.de
- fix typo in makedeltarpm [bnc#431509]
* Fri May  9 2008 mls@suse.de
- fix deltaisos with no rpms [bnc#386847]
- remove bogus write to fd3 that was added for debugging
- update drpmsync
* Sun May  4 2008 coolo@suse.de
- make lzma deltarpm available on older distris
* Tue Apr 22 2008 mls@suse.de
- add support for lzma payloads
* Mon Mar 12 2007 mls@suse.de
- update to deltarpm-3.4:
  * fixes some bugs in the prelink code
  * includes percent and fragiso patch
* Tue Sep  5 2006 mls@suse.de
- added fragiso support
- flush percent output
- updated drpmsync to current release
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Oct 11 2005 mls@suse.de
- update to deltarpm-3.3 [#121866]
* Mon Sep  5 2005 mls@suse.de
- update to deltarpm-3.2
* Mon Aug 22 2005 mls@suse.de
- update to deltarpm-3.1
* Thu Aug 18 2005 cthiel@suse.de
- use $RPM_OPT_FLAGS
* Wed Aug 10 2005 mls@suse.de
- update to final deltarpm-3.0
* Thu Jun 30 2005 mls@suse.de
- update to deltarpm-3.0-beta3
* Wed Mar 16 2005 mls@suse.de
- update to deltarpm-2.2
* Wed Feb 16 2005 mls@suse.de
- update to deltarpm-2.1
* Thu Feb  3 2005 mls@suse.de
- update to deltarpm-2.0
* Fri Sep 24 2004 mls@suse.de
- always flush stdout when printing percent data
* Mon Sep 20 2004 mls@suse.de
- fix bad calloc call
* Fri Sep 10 2004 mls@suse.de
- initial version
